USE [igops]
GO

DROP VIEW IF EXISTS spermission_v
DROP VIEW IF EXISTS suser_account_permission_v
GO

CREATE VIEW spermission_v AS
SELECT
  spermission.id,
  spermission.account_grant,
  spermission.assignable,
  spermission.authoritative,
  spermission.bound_by_id,
  spermission.boundable,
  spermission.cost,
  spermission.deleted,
  spermission.description,
  spermission.display_name,
  spermission.driver_id,
  spermission.effective,
  spermission.exclude_from_catalog,
  spermission.is_curated,
  spermission.logical_id,
  spermission.merged,
  spermission.name,
  spermission.not_reviewable,
  spermission.permission_id,
  spermission.prov_attribute,
  spermission.prov_by_unique_permission_id,
  spermission.prov_native_value,
  spermission.prov_unique_driver_id,
  spermission.provisionable,
  spermission.risk,
  spermission.type,
  spermission.unique_bound_by_id,
  spermission.unique_permission_id,
  spermission.value,
  spermission.value_type,
  spermission.application,
  spermission.base_application,
  spermission.collected_entity,
  spermission.data_collection,
  spermission.effective_entity,
  spermission.sversion,
  spermission.auto_generated,
  spermission.prov_unique_permission_id,
  perm_owner.perm_owner_name
FROM 
  spermission
  LEFT JOIN (SELECT 
        rso.permission,
        STUFF((SELECT DISTINCT ' | ' + suser.display_name FROM resolved_spermission_owner rso1
        JOIN (SELECT unique_user_id, display_name FROM suser WHERE suser.deleted = '0' AND suser.effective = '1') suser ON suser.unique_user_id = rso1.owner_unique_id
        WHERE rso1.permission = rso.permission
        FOR XML PATH('')),1,3,'') perm_owner_name
        FROM (SELECT DISTINCT owner_unique_id, permission
                  FROM resolved_spermission_owner) rso
                  JOIN suser ON suser.unique_user_id = rso.owner_unique_id AND suser.deleted = '0' AND suser.effective = '1'
          GROUP BY rso.permission) perm_owner ON perm_owner.permission = spermission.id
WHERE 
  (exclude_from_catalog = 0 OR exclude_from_catalog IS NULL) AND effective = 1

GO


CREATE VIEW suser_account_permission_v AS
    select
        case when sap.id is not null then
            convert(nvarchar(30),sau.id) + '.' + convert(nvarchar(30),sap.id)
        else
            convert(nvarchar(30),sau.id) + '.null'
        end as id,
        su.id as suser,
        su.collected_entity as collected_entity,
        sa.id as saccount,
        sp.id as spermission,
        sau.sversion as sversion,
        sau.id as saccount_user,
        sap.id as saccount_permission,
        sap.value as spermission_value,
        case when (sa.virtual is null or sa.virtual = 0) then
            sau.id
        else
            null
        end as real_saccount_user
    from saccount_user sau
    join saccount sa on sa.collected_entity = sau.saccount and sa.effective = 1 and sa.deleted = 0
    join suser su on su.collected_entity = sau.suser and su.effective = 1 and su.deleted = 0
    left join saccount_permission sap on sap.saccount = sau.saccount and sap.effective = 1
    left join spermission sp on sp.collected_entity = sap.spermission and sp.effective = 1 and sp.deleted = 0
    where
        sau.effective = 1
GO
GRANT SELECT ON spermission_v TO ig_report_role
GRANT SELECT ON suser_account_permission_v TO ig_report_role
GO