DROP VIEW IF EXISTS spermission_v;
DROP VIEW IF EXISTS suser_account_permission_v;


CREATE VIEW spermission_v AS
SELECT spermission.id,
    spermission.account_grant,
    spermission.assignable,
    spermission.authoritative,
    spermission.bound_by_id,
    spermission.boundable,
    spermission.cost,
    spermission.deleted,
    spermission.description,
    spermission.display_name,
    spermission.driver_id,
    spermission.effective,
    spermission.exclude_from_catalog,
    spermission.is_curated,
    spermission.logical_id,
    spermission.merged,
    spermission.name,
    spermission.not_reviewable,
    spermission.permission_id,
    spermission.prov_attribute,
    spermission.prov_by_unique_permission_id,
    spermission.prov_native_value,
    spermission.prov_unique_driver_id,
    spermission.provisionable,
    spermission.risk,
    spermission.type,
    spermission.unique_bound_by_id,
    spermission.unique_permission_id,
    spermission.value,
    spermission.value_type,
    spermission.application,
    spermission.base_application,
    spermission.collected_entity,
    spermission.data_collection,
    spermission.effective_entity,
    spermission.sversion,
    spermission.auto_generated,
    spermission.prov_unique_permission_id,
    perm_owner.perm_owner_name
   FROM spermission
     LEFT JOIN (SELECT rso.permission,
            string_agg(suser.display_name::text, ' | '::text) AS perm_owner_name
           FROM (SELECT DISTINCT owner_unique_id,
                permission
                FROM resolved_spermission_owner) rso
             JOIN suser ON suser.unique_user_id::text = rso.owner_unique_id::text AND suser.deleted = false AND suser.effective = true
          GROUP BY rso.permission) perm_owner ON perm_owner.permission = spermission.id
  WHERE (spermission.exclude_from_catalog = false OR spermission.exclude_from_catalog IS NULL) AND spermission.effective = true;


CREATE VIEW suser_account_permission_v AS 
 SELECT
        CASE
            WHEN sap.id IS NOT NULL THEN (sau.id || '.') || sap.id
            ELSE sau.id || '.null'
        END AS id,
    su.id AS suser,
    su.collected_entity,
    sa.id AS saccount,
    sp.id AS spermission,
    sau.sversion,
    sau.id AS saccount_user,
    sap.id AS saccount_permission,
    sap.value AS spermission_value,
        CASE
            WHEN sa.virtual IS NULL OR sa.virtual = false THEN sau.id
        END AS real_saccount_user
   FROM saccount_user sau
     JOIN saccount sa ON sa.collected_entity = sau.saccount AND sa.effective = true AND sa.deleted = false
     JOIN suser su ON su.collected_entity = sau.suser AND su.effective = true AND su.deleted = false
     LEFT JOIN saccount_permission sap ON sap.saccount = sau.saccount AND sap.effective = true
     LEFT JOIN spermission sp ON sp.collected_entity = sap.spermission AND sp.effective = true AND sp.deleted = false
  WHERE sau.effective = true;


ALTER TABLE spermission_v
  OWNER TO igops;
GRANT ALL ON TABLE spermission_v TO igops;
GRANT SELECT ON TABLE spermission_v TO ig_report_role;

ALTER TABLE suser_account_permission_v
  OWNER TO igops;
GRANT ALL ON TABLE suser_account_permission_v TO igops;
GRANT SELECT ON TABLE suser_account_permission_v TO ig_report_role;